@@ -3,6 +3,7 @@ from enum import Enum
 
 class TaskStatus(Enum):
     PROCESSING = "processing"
+    PREPARED = "prepared"
     QUEUED = "queued"
     RUNNING = "running"
     COMPLETED = "completed"
@@ -27,6 +28,9 @@ class TaskStatus(Enum):
             TaskStatus.SUSPENDED,
         ]
 
+    def is_in_final_state(self):
+        return self in self.final_states()
+
     def __str__(self):
         __str = {
             TaskStatus.PROCESSING.value: "Processing",
@@ -39,6 +43,7 @@ class TaskStatus(Enum):
             TaskStatus.ON_HOLD.value: "On hold",
             TaskStatus.ABORTING.value: "Aborting",
             TaskStatus.SUSPENDED.value: "Suspended",
+            TaskStatus.PREPARED.value: "Prepared",
         }
         return __str[self.value]
 
@@ -54,5 +59,13 @@ class TaskStatus(Enum):
             TaskStatus.ON_HOLD.value: "?",
             TaskStatus.ABORTING.value: "~x",
             TaskStatus.SUSPENDED.value: "II",
+            TaskStatus.PREPARED.value: ":",
         }
         return __str[self.value]
+
+    def to_hexcolor(self):
+        __str = {
+            TaskStatus.FAILED.value: "#a63030",
+        }
+
+        return __str.get(self.value)
