@@ -1,6 +1,14 @@
 from typing import Dict, List
 
-from janis_core import Tool, WorkflowBuilder, Workflow, Array, InputSelector
+from janis_core import (
+    Tool,
+    WorkflowBuilder,
+    Workflow,
+    Array,
+    InputSelector,
+    WorkflowBase,
+)
+from janis_core.operators.operator import Operator, Selector
 from janis_core.utils import find_duplicates, validators
 from janis_core.utils.validators import Validators
 
@@ -75,7 +83,7 @@ class BatchPipelineModifier(PipelineModifierBase):
 
         steps_created = []
 
-        stepid_from_gb = lambda gb: f"{gbvalue}_{tool.id()}"
+        stepid_from_gb = lambda gb: f"{gb}_{tool.id()}"
 
         for gbvalue in groupby_values:
 
@@ -88,43 +96,26 @@ class BatchPipelineModifier(PipelineModifierBase):
                 w.step(stepid_from_gb(gbvalue), tool(**innode_base, **extra_ins))
             )
 
-        def transform_token_in_output_namers(token, outputid):
-            if token is None:
-                return token
-            if isinstance(token, list):
-                return [transform_token_in_output_namers(t, outputid) for t in token]
-            if isinstance(token, InputSelector):
-                if token.input_to_select in fields:
-                    # need to transform it
-                    return InputSelector(f"{token.input_to_select}_{outputid}")
-                else:
-                    return token
-            elif isinstance(token, (str, int, float, bool)):
-                return token
-            else:
-                raise Exception(
-                    f"Unsure how to translate token of type {token.__class__.__name__} "
-                )
-
         for out in tool.tool_outputs():
             output_folders = []
             output_name = out.id()
-            if isinstance(tool, Workflow):
+            if isinstance(tool, WorkflowBase):
                 outnode = tool.output_nodes[out.id()]
                 output_folders = outnode.output_folder or []
 
-                if outnode.output_name:
+                if outnode.output_name is not None:
                     output_name = outnode.output_name
 
-            for gbvalue, raw_gbvalue in zip(groupby_values, raw_groupby_values):
-                # This is pretty hacky, we're relying on the output_folder and output_name to be InputSelectors
-                # or a literal value, otherwise this will probably break (this will probably break for expressions)
+            for idx, gbvalue, raw_gbvalue in zip(
+                range(len(groupby_values)), groupby_values, raw_groupby_values
+            ):
+                transformed_inputs = {**inputs, **{f: inputs[f][idx] for f in fields}}
 
-                output_folders_transformed = transform_token_in_output_namers(
-                    output_folders, gbvalue
+                output_folders_transformed = Operator.evaluate_arg(
+                    output_folders, transformed_inputs
                 )
-                output_name_transformed = transform_token_in_output_namers(
-                    output_name, gbvalue
+                output_name_transformed = Operator.evaluate_arg(
+                    output_name, transformed_inputs
                 )
 
                 w.output(
